@@ -62,10 +62,12 @@ def check_row(row):
 class Subtask:
     name: str
     max_points: float
+    half_points: float
 
     def __init__(self, name: str, max_points: float):
         self.name = name
         self.max_points = max_points
+        self.half_points = max_points / 2
 
 
 class Ep2Group:
@@ -421,17 +423,13 @@ class Ep2:
 
             return subtasks
 
-    def validate_grading(self, ex: int, grading: str) -> (bool, [float]):
+    def validate_grading(self, ex: int, grading: str) -> (bool, str):
         subtasks = self.get_exercise_subtasks(ex)
-        grading = grading.split('/')
 
         if len(subtasks) != len(grading):
             return False, []
 
-        grading = [float(grade) for grade in grading]
-        correct = all([grade <= max_points for (grade, max_points) in zip(grading, [subtask.max_points for subtask in subtasks])])
-
-        return correct, grading
+        return True, grading
 
 
 def verify_and_normalize_student_id(student_id) -> Result:
