@@ -180,11 +180,11 @@ def validate_grading(ctx, param, value):
         return value
     if value is None:
         return value
-    match = re.match('^((\\d*\\.\\d+|\\d+\\.?)/)*(\\d*\\.\\d+|\\d+\\.?)$', value)
+    match = re.match('^[+\\-~0]*$', value)
     if match is not None:
         return value
     else:
-        raise click.BadParameter('can only consist of a slash separated list of numbers')
+        raise click.BadParameter('can only consist of [\'+\', \'~\', \'-\', \'0\']')
 
 
 def validate_ex_type(ctx, param, value):
@@ -237,7 +237,7 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
     elif curr_ue_type == ExerciseType.Normal:
         if grading is None:
             grading = click.prompt('Grading')
-            while not re.match('^((\\d*\\.\\d+|\\d+\\.?)/)*(\\d*\\.\\d+|\\d+\\.?)$', grading):
+            while not re.match('^[+\\-~0]*$', grading):
                 grading = click.prompt('Grading')
     else:
         click.secho('Unknown exercise type %s' % curr_ue_type, fg='red')
@@ -246,7 +246,7 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
     grading_correct, grading = ep2.validate_grading(ue, grading)
 
     if not grading_correct:
-        click.secho('Some gradings are above the maximum point value')
+        click.secho('length of grading does not match number of subtasks')
         exit(2)
 
     try:
@@ -296,7 +296,7 @@ def grade(ctx, group, ue: int, student, grading, student_feedback, solution_rema
                 if curr_ue_type == ExerciseType.Normal:
                     student_id = row[KEY_STUDENT_ID]
                     if student_id == student:
-                        row[KEY_UE_GRADING] = "/".join([str(grade) for grade in grading])
+                        row[KEY_UE_GRADING] = grading
 
                         if solution_remarks is not None:
                             row[KEY_UE_REMARKS] = escape_csv_string(solution_remarks)
@@ -422,17 +422,17 @@ def submit(ctx, group: str, ue: int):
                     grading_correct, grading = ep2.validate_grading(ue, grading)
 
                     if not grading_correct:
-                        click.secho('the grading for student {} is not correct. (either wrong number of subgrades or '
-                                    'subgrade > max_points for subgrade)'.format(row[KEY_STUDENT_ID]))
+                        click.secho('the grading for student {} is not correct. (possibly wrong number of subgrades)'
+                                    .format(row[KEY_STUDENT_ID]))
 
                     template.grading = grading
                     if len(template.grading) < len(template.subtasks):
-                        template.grading += [float(0)] * (len(template.subtasks) - len(template.grading))
+                        template.grading += '-' * (len(template.subtasks) - len(template.grading))
 
                     template.tests = [row[KEY_UE_PRE_EVAL_EX % d] for d in range(1, ep2.tests_for_exercise(ue) + 1)]
                     template.points = -1
 
-                    row[KEY_UE_GRADING] = "/".join([str(grade) for grade in grading])
+                    row[KEY_UE_GRADING] = template.grading
 
                 elif curr_ue_type == ExerciseType.Team:
                     points = row[KEY_UE_TA_POINTS]
